# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Suportada Versão do Python 3


[![Updates](https://pyup.io/repos/github/Aislanfagundes/libpythonpro/shield.svg)](https://pyup.io/repos/github/Aislanfagundes/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/Aislanfagundes/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Aislanfagundes/libpythonpro/)

Para instalar:

"""
console
python3 -m venv .venv
source .venv\Scripts\activate
pip install -r requirements-dev.txt
"""

Para conferir qualidade do código:

'''
console
flake8
'''